##----------------------------------------------------------------------------
## Copyright (c) Axis Communications AB, SWEDEN. All rights reserved.
##----------------------------------------------------------------------------

<#
    .SYNOPSIS
     Add component string constants to this file.
     Update this template if you are adding to this repo.
     This file should be placed in the solution root.
#>

# Version constants for the component
$ComponentVersions = @{
    axisBuildBootstrapVersion = "5.0.0"
    nugetScriptVersion        = "5.0.3"

    # bundled    = "1.1.0"
    # notBundled = "0.1.0"
    # legacy     = "1.0.0"
    componentBaseVersion      = "0.1.0"
}

# Name of script nuget
$NugetScriptConstants = @{
    nugetName                 = "Axis.Component.Scripts"
    nugetScriptsPath          = "BuildScripts"
    nugetRestoreUri           = "https://artifacts.se.axis.com/artifactory/api/nuget/v3/vms-nuget-all-se/index.json"
    nugetModulesDirectoryName = "Tools"
    nugetLoadModulesFileName  = "Load-ScriptModules.ps1"
}

# Solution specific constants
$SolutionConstants = [ordered]@{
    componentSolutionPath                = ($componentSolutionPath = $PSScriptRoot)
    projectName                          = ($projectName = "Sr.Plugin")
    projectPath                          = ($projectPath = Join-Path $componentSolutionPath $projectName)
    metadataFilePath                     = Join-Path $projectPath "metadata.json"
    metadataId                           = "recordingreplicator" # Should not change between versions
    metadataIdCamelCase                  = "RecordingReplicator" # For naming conventions
    metaDataName                         = "AXIS Recording Replicator"
    solutionName                         = ($solutionName = "acs-storage-redundancy")
    stringConstantsFilePath              = Join-Path $componentSolutionPath "StringConstants.ps1" # Place in solution root
    solutionFilePath                     = "$(Join-Path $componentSolutionPath $solutionName).sln"
    componentCsprojFilePath              = "$(Join-Path $projectPath $projectName).csproj"
    componentFilesToIncludeInPackagePath = Join-Path $componentSolutionPath "ComponentFilesToZip"
    packageJsonPath                      = Join-Path $projectPath "wwwroot\package.json"
    acsScriptsDirectoryPath              = Join-Path $projectPath "AcsScripts"

    binaryFile                           = "Sr.Plugin.exe" # improve
}

# Component nuget constants
$componentNugetConstants = [ordered]@{
    # Nuget-package naming conventions https://confluence.se.axis.com/pages/viewpage.action?spaceKey=MS&title=How+to+create+a+component+NuGet-package
    nuspecId                 = ($nuspecId = "Axis.Acs.Component.$($SolutionConstants.metadataIdCamelCase)")
    description              = "This component replicates videos between servers."
    signedComponentFileName  = "Signed$($SolutionConstants.metadataIdCamelCase).zip"
    nuspecFileName           = ($nuspecFileName = "$nuspecId.nuspec")
    targetsFileName          = ($targetsFileName = "$nuspecId.targets")
    nuspecFilePath           = Join-Path $SolutionConstants.projectPath $nuspecFileName
    targetsFilePath          = Join-Path $SolutionConstants.projectPath $targetsFileName

    # Each ACS component's SBOM file shall be named <ComponentName>_sbom.<format>.json (component name in pascal case and rest in lower case, format being e.g. "cyclonedx" or "spdx")  
    sbomFileBackEndName      = ($sbomFileBackEndName = "$($SolutionConstants.metadataIdCamelCase)_service_sbom.cyclonedx.json")
    sbomFileFrontEndName     = ($sbomFileFrontEndName = "$($SolutionConstants.metadataIdCamelCase)_ui_sbom.cyclonedx.json")
    sbomFileBackEndFilePath  = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $sbomFileBackEndName
    sbomFileFrontEndFilePath = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $sbomFileFrontEndName
}

# Service Specific Constants
$ServiceConstants = @{
    serviceName        = "AXISCameraStationRecordingReplicatorService"
    serviceDisplayName = "AXIS Recording Replicator"
    serviceStartupType = "Manual"
    serviceDescription = "Service for AXIS Recording Replicator. Used to replicate videos between servers."
}

# Constants used for packing and publishing
$componentPublishConstants = [ordered]@{
    componentSignUri        = "https://acs-plugin-sign.se.axis.com/sign"
    componentSignHeader     = "Bearer ${env:BearerToken}"
    zippedComponentFilePath = ($zippedComponentFilePath = "$(Join-Path $SolutionConstants.componentSolutionPath $SolutionConstants.metadataIdCamelCase).zip")
    componentSignFormData   = "plugin=@$zippedComponentFilePath"
    signedComponentFilePath = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $componentNugetConstants.signedComponentFileName
    nugetPackageExePath     = "$env:SATOOLS\nuget6.exe"
}

# Third party specific constants
$ThirdPartyLicenseConstants = [ordered]@{
    licenseName                   = ($licenseName = "third-party-licenses")
    licenseFileName               = ($licenseFileName = "$licenseName.txt")
    thirdPartyLicenseTxtFilePath  = Join-Path $SolutionConstants.componentSolutionPath $licenseFileName
    thirdPartyLicenseJsonFilePath = Join-Path $SolutionConstants.componentSolutionPath "$licenseName.json"
}

$fileStructureConstants = @{
    dataDirPathName = "Data"
    logDirPathName  = "Logs"
    scriptLogName   = "scripts.log"
}

# Project GUIDs  to exclude from the SBOM
#
# Each project is declared with the following syntax in the solution file:
#
# Project("{<project type GUID>}") = "<project name>", "<project file location>", "{<project GUID>}"
# EndProject
$projectIdsToExclude = @(
    "9820B0EA-3FB0-4787-A333-14E505F4AF8C" # Sr.Plugin.Test
)
# SIG # Begin signature block
# MIIoGwYJKoZIhvcNAQcCoIIoDDCCKAgCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCAJKMINLbEeFq7y
# 8wlM0R1qkXNuyyiHObdbvLsdP/1H7qCCDY4wggawMIIEmKADAgECAhAIrUCyYNKc
# TJ9ezam9k67ZMA0GCSqGSIb3DQEBDAUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNV
# BAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9vdCBHNDAeFw0yMTA0MjkwMDAwMDBaFw0z
# NjA0MjgyMzU5NTlaMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
# ggIKAoICAQDVtC9C0CiteLdd1TlZG7GIQvUzjOs9gZdwxbvEhSYwn6SOaNhc9es0
# JAfhS0/TeEP0F9ce2vnS1WcaUk8OoVf8iJnBkcyBAz5NcCRks43iCH00fUyAVxJr
# Q5qZ8sU7H/Lvy0daE6ZMswEgJfMQ04uy+wjwiuCdCcBlp/qYgEk1hz1RGeiQIXhF
# LqGfLOEYwhrMxe6TSXBCMo/7xuoc82VokaJNTIIRSFJo3hC9FFdd6BgTZcV/sk+F
# LEikVoQ11vkunKoAFdE3/hoGlMJ8yOobMubKwvSnowMOdKWvObarYBLj6Na59zHh
# 3K3kGKDYwSNHR7OhD26jq22YBoMbt2pnLdK9RBqSEIGPsDsJ18ebMlrC/2pgVItJ
# wZPt4bRc4G/rJvmM1bL5OBDm6s6R9b7T+2+TYTRcvJNFKIM2KmYoX7BzzosmJQay
# g9Rc9hUZTO1i4F4z8ujo7AqnsAMrkbI2eb73rQgedaZlzLvjSFDzd5Ea/ttQokbI
# YViY9XwCFjyDKK05huzUtw1T0PhH5nUwjewwk3YUpltLXXRhTT8SkXbev1jLchAp
# QfDVxW0mdmgRQRNYmtwmKwH0iU1Z23jPgUo+QEdfyYFQc4UQIyFZYIpkVMHMIRro
# OBl8ZhzNeDhFMJlP/2NPTLuqDQhTQXxYPUez+rbsjDIJAsxsPAxWEQIDAQABo4IB
# WTCCAVUwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUaDfg67Y7+F8Rhvv+
# YXsIiGX0TkIwHwYDVR0jBBgwFoAU7NfjgtJxXWRM3y5nP+e6mK4cD08wDgYDVR0P
# AQH/BAQDAgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMDMHcGCCsGAQUFBwEBBGswaTAk
# BggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAC
# hjVodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9v
# dEc0LmNydDBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8vY3JsMy5kaWdpY2VydC5j
# b20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNybDAcBgNVHSAEFTATMAcGBWeBDAED
# MAgGBmeBDAEEATANBgkqhkiG9w0BAQwFAAOCAgEAOiNEPY0Idu6PvDqZ01bgAhql
# +Eg08yy25nRm95RysQDKr2wwJxMSnpBEn0v9nqN8JtU3vDpdSG2V1T9J9Ce7FoFF
# UP2cvbaF4HZ+N3HLIvdaqpDP9ZNq4+sg0dVQeYiaiorBtr2hSBh+3NiAGhEZGM1h
# mYFW9snjdufE5BtfQ/g+lP92OT2e1JnPSt0o618moZVYSNUa/tcnP/2Q0XaG3Ryw
# YFzzDaju4ImhvTnhOE7abrs2nfvlIVNaw8rpavGiPttDuDPITzgUkpn13c5Ubdld
# AhQfQDN8A+KVssIhdXNSy0bYxDQcoqVLjc1vdjcshT8azibpGL6QB7BDf5WIIIJw
# 8MzK7/0pNVwfiThV9zeKiwmhywvpMRr/LhlcOXHhvpynCgbWJme3kuZOX956rEnP
# LqR0kq3bPKSchh/jwVYbKyP/j7XqiHtwa+aguv06P0WmxOgWkVKLQcBIhEuWTatE
# QOON8BUozu3xGFYHKi8QxAwIZDwzj64ojDzLj4gLDb879M4ee47vtevLt/B3E+bn
# KD+sEq6lLyJsQfmCXBVmzGwOysWGw/YmMwwHS6DTBwJqakAwSEs0qFEgu60bhQji
# WQ1tygVQK+pKHJ6l/aCnHwZ05/LWUpD9r4VIIflXO7ScA+2GRfS0YW6/aOImYIbq
# yK+p/pQd52MbOoZWeE4wggbWMIIEvqADAgECAhAILYwW0nV0JkMDtityXUvoMA0G
# CSqGSIb3DQEBCwUAMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwHhcNMjQwMjEyMDAwMDAwWhcNMjcwMjEx
# MjM1OTU5WjBeMQswCQYDVQQGEwJTRTENMAsGA1UEBxMETHVuZDEfMB0GA1UEChMW
# QXhpcyBDb21tdW5pY2F0aW9ucyBBQjEfMB0GA1UEAxMWQXhpcyBDb21tdW5pY2F0
# aW9ucyBBQjCCAaIwDQYJKoZIhvcNAQEBBQADggGPADCCAYoCggGBAOk0Sr22C6QH
# zDpps6p3+m4c4HrGKW9dju1+awvCWpNnrTrCxxcqC7Fexgt3VVR2GfI+hEHrkSV9
# hq7tCT20No1s4OqGdB/FasUvqq8jCuoXKQQnd5gqFhFz/aL+1ocr2NvtCsxuNihB
# UA3isiFf0R0uXcEIoi+tUiy0vJf5ZstopMEuSSOZlANhdWvwBTd8DL1EBYDp4Z/t
# 1kWLax6NI8fim1MJxi5OaVUd1haFQMbzeBiwDXlMVJCyYcSVH7fuKCRhoem4pX1g
# fdbM3yfhigegJPRui13ai6I69X71GoyRCBnkCgkrw8nUrOHGjrTe90sXLvVSU0Yu
# j3VZzcDkdxN16tHG2SK3NT/7d5EmgrUSwabvS36sTRy0VeSCmop4ByDlTUCljGiP
# cDO5viiyDF9SRbKa0BSuVAB9xtaaqjw9+sWRxiUqHVq8cRPOylBcziOMVFSE4ENc
# aH3A55N2kb2tBalRm0GPfvB1wRzHdow/ArdGYB1FYIrBi2IUcUsgKwIDAQABo4IC
# AzCCAf8wHwYDVR0jBBgwFoAUaDfg67Y7+F8Rhvv+YXsIiGX0TkIwHQYDVR0OBBYE
# FCCITo81URSaUaiF+AwqLquw/5UcMD4GA1UdIAQ3MDUwMwYGZ4EMAQQBMCkwJwYI
# KwYBBQUHAgEWG2h0dHA6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAOBgNVHQ8BAf8E
# BAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMwgbUGA1UdHwSBrTCBqjBToFGgT4ZN
# aHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZEc0Q29kZVNp
# Z25pbmdSU0E0MDk2U0hBMzg0MjAyMUNBMS5jcmwwU6BRoE+GTWh0dHA6Ly9jcmw0
# LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENvZGVTaWduaW5nUlNBNDA5
# NlNIQTM4NDIwMjFDQTEuY3JsMIGUBggrBgEFBQcBAQSBhzCBhDAkBggrBgEFBQcw
# AYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMFwGCCsGAQUFBzAChlBodHRwOi8v
# Y2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkRzRDb2RlU2lnbmlu
# Z1JTQTQwOTZTSEEzODQyMDIxQ0ExLmNydDAJBgNVHRMEAjAAMA0GCSqGSIb3DQEB
# CwUAA4ICAQBTl/rp/1EMC6RXuNwZmY8QNQpzSOODOmLbFU1hMlHq/iipWO+tsAnH
# fB4CnZlrbgkVa64syckD29gWMrYp2PMdTwsL/vHmUI0lZj1pJ3zCvB5E+4CnKkhY
# SIre1yukMyzbHR5y5X2bQ6kVtR0mkKqDTrT+vm6abBMmNcVwc+j5IJ9viHspncAs
# X/t7gnYDmMnHCWTQwR01wNYypEbmpf5ZtF8233I5toy+x2TGBx7PToduYzxWiF9G
# Hd18UNGuyNjsLPnHI0cY3vGNMo5GiaisR9e/CHYUq149MduRRifz9kkq8JA81k0j
# +DEsZb8lOORoA7gte007xnesv35OL4ezbfhjkKYICGjRVSB/Xu8YhH04Xs6AbFWB
# Boqi9/DH9RV3S0LH+JzxNIeDUw8LW7VNYrSOHWuRqPSazmtWll+MQUDV0p4LIUMl
# EjoUNsRBvsDYSMiZSTNizMgyp437XDv25+iO8GMtiKlymsOPuKYALFVn0TJxdIet
# ID0HnXa560C3FysEDxsGbVCI6L1l9j5RCmmF1qUs7o2oczvlDyplesA0sNOSlpJF
# xyTgvlXXloxJCH7Yaz/2ItvhfMt1CZhMtyp38Y1yWlgMqSTrlJVxAcXHOXzu/mEM
# aNvDTqF/zGnW5todKFHL092hQqm+8xGNOjL0C8G+ByZ2tzSh3y1R7jGCGeMwghnf
# AgEBMH0waTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMUEw
# PwYDVQQDEzhEaWdpQ2VydCBUcnVzdGVkIEc0IENvZGUgU2lnbmluZyBSU0E0MDk2
# IFNIQTM4NCAyMDIxIENBMQIQCC2MFtJ1dCZDA7Yrcl1L6DANBglghkgBZQMEAgEF
# AKB8MBAGCisGAQQBgjcCAQwxAjAAMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEE
# MBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEiBCAt
# sqO+Gki3w1GKIyC+gAEtKwYLiLjfnRlFWo9scjY3qTANBgkqhkiG9w0BAQEFAASC
# AYDd5I4lJj2DToC+dv+CflpcNAYcq9ElcXACj4aTMFIPZLL+WQ9V82Ni/nRYHykv
# n/SIZ1mla8UadNQJFjCtyezgtGUGAKxzWyHWIkkRxAr/cmWNnO14f9rZ1zcHJhXc
# ZXkvg/AcPi63s/ixqKoIKXehNIazsnphfVknRIvKNUl1xIjV5LtmxPyxH4+qaKmH
# c1Sxc2A+KJlL9KHwD0Y99RDYcpt8LOZ7gzzD36Lqp/1IXJ0pSl16lFsEFFM4K+Rj
# r85pUFl9xPjbBbFLOS7l2166FbKlZ9f7ZXu3mCiOwgv5UQ5JjNvKaSP3mHwXpFF3
# D/qc7tS2jEFBHSqiFXPHPJg+eKDdMNNhdgzXRPjy6b2/TnUgTqYH5y9CFUZp6TTA
# wVXMnpRvcF/Ym8QPGOU5WuUlFUNxnCuOEcHFwuC11rywCvrTX86hNGvWDAn1V8aH
# eQ1aSqTcBSN/zN5cR8jkRa6P/+5eaw8jzkSEt+gpXfMino1vuKUrYChFo1i2nwDu
# gTKhghc5MIIXNQYKKwYBBAGCNwMDATGCFyUwghchBgkqhkiG9w0BBwKgghcSMIIX
# DgIBAzEPMA0GCWCGSAFlAwQCAQUAMHcGCyqGSIb3DQEJEAEEoGgEZjBkAgEBBglg
# hkgBhv1sBwEwMTANBglghkgBZQMEAgEFAAQg5WkgfkG9Kez8B9Wlmd236yWcdgA6
# Xa6EEwd/EjtTWFwCEDbwBeG1iWtdbO+EypKIWScYDzIwMjQxMjEwMTEwNjExWqCC
# EwMwgga8MIIEpKADAgECAhALrma8Wrp/lYfG+ekE4zMEMA0GCSqGSIb3DQEBCwUA
# MGMxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwgSW5jLjE7MDkGA1UE
# AxMyRGlnaUNlcnQgVHJ1c3RlZCBHNCBSU0E0MDk2IFNIQTI1NiBUaW1lU3RhbXBp
# bmcgQ0EwHhcNMjQwOTI2MDAwMDAwWhcNMzUxMTI1MjM1OTU5WjBCMQswCQYDVQQG
# EwJVUzERMA8GA1UEChMIRGlnaUNlcnQxIDAeBgNVBAMTF0RpZ2lDZXJ0IFRpbWVz
# dGFtcCAyMDI0MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAvmpzn/aV
# IauWMLpbbeZZo7Xo/ZEfGMSIO2qZ46XB/QowIEMSvgjEdEZ3v4vrrTHleW1JWGEr
# rjOL0J4L0HqVR1czSzvUQ5xF7z4IQmn7dHY7yijvoQ7ujm0u6yXF2v1CrzZopykD
# 07/9fpAT4BxpT9vJoJqAsP8YuhRvflJ9YeHjes4fduksTHulntq9WelRWY++TFPx
# zZrbILRYynyEy7rS1lHQKFpXvo2GePfsMRhNf1F41nyEg5h7iOXv+vjX0K8RhUis
# fqw3TTLHj1uhS66YX2LZPxS4oaf33rp9HlfqSBePejlYeEdU740GKQM7SaVSH3Tb
# BL8R6HwX9QVpGnXPlKdE4fBIn5BBFnV+KwPxRNUNK6lYk2y1WSKour4hJN0SMkoa
# NV8hyyADiX1xuTxKaXN12HgR+8WulU2d6zhzXomJ2PleI9V2yfmfXSPGYanGgxzq
# I+ShoOGLomMd3mJt92nm7Mheng/TBeSA2z4I78JpwGpTRHiT7yHqBiV2ngUIyCtd
# 0pZ8zg3S7bk4QC4RrcnKJ3FbjyPAGogmoiZ33c1HG93Vp6lJ415ERcC7bFQMRbxq
# rMVANiav1k425zYyFMyLNyE1QulQSgDpW9rtvVcIH7WvG9sqYup9j8z9J1XqbBZP
# J5XLln8mS8wWmdDLnBHXgYly/p1DhoQo5fkCAwEAAaOCAYswggGHMA4GA1UdDwEB
# /wQEAwIHgDAMBgNVHRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMCAG
# A1UdIAQZMBcwCAYGZ4EMAQQCMAsGCWCGSAGG/WwHATAfBgNVHSMEGDAWgBS6Ftlt
# TYUvcyl2mi91jGogj57IbzAdBgNVHQ4EFgQUn1csA3cOKBWQZqVjXu5Pkh92oFsw
# WgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lD
# ZXJ0VHJ1c3RlZEc0UlNBNDA5NlNIQTI1NlRpbWVTdGFtcGluZ0NBLmNybDCBkAYI
# KwYBBQUHAQEEgYMwgYAwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0
# LmNvbTBYBggrBgEFBQcwAoZMaHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0Rp
# Z2lDZXJ0VHJ1c3RlZEc0UlNBNDA5NlNIQTI1NlRpbWVTdGFtcGluZ0NBLmNydDAN
# BgkqhkiG9w0BAQsFAAOCAgEAPa0eH3aZW+M4hBJH2UOR9hHbm04IHdEoT8/T3HuB
# SyZeq3jSi5GXeWP7xCKhVireKCnCs+8GZl2uVYFvQe+pPTScVJeCZSsMo1JCoZN2
# mMew/L4tpqVNbSpWO9QGFwfMEy60HofN6V51sMLMXNTLfhVqs+e8haupWiArSozy
# AmGH/6oMQAh078qRh6wvJNU6gnh5OruCP1QUAvVSu4kqVOcJVozZR5RRb/zPd++P
# GE3qF1P3xWvYViUJLsxtvge/mzA75oBfFZSbdakHJe2BVDGIGVNVjOp8sNt70+kE
# oMF+T6tptMUNlehSR7vM+C13v9+9ZOUKzfRUAYSyyEmYtsnpltD/GWX8eM70ls1V
# 6QG/ZOB6b6Yum1HvIiulqJ1Elesj5TMHq8CWT/xrW7twipXTJ5/i5pkU5E16RSBA
# dOp12aw8IQhhA/vEbFkEiF2abhuFixUDobZaA0VhqAsMHOmaT3XThZDNi5U2zHKh
# Us5uHHdG6BoQau75KiNbh0c+hatSF+02kULkftARjsyEpHKsF7u5zKRbt5oK5YGw
# Fvgc4pEVUNytmB3BpIiowOIIuDgP5M9WArHYSAR16gc0dP2XdkMEP5eBsX7bf/MG
# N4K3HP50v/01ZHo/Z5lGLvNwQ7XHBx1yomzLP8lx4Q1zZKDyHcp4VQJLu2kWTsKs
# OqQwggauMIIElqADAgECAhAHNje3JFR82Ees/ShmKl5bMA0GCSqGSIb3DQEBCwUA
# MGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsT
# EHd3dy5kaWdpY2VydC5jb20xITAfBgNVBAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9v
# dCBHNDAeFw0yMjAzMjMwMDAwMDBaFw0zNzAzMjIyMzU5NTlaMGMxCzAJBgNVBAYT
# AlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwgSW5jLjE7MDkGA1UEAxMyRGlnaUNlcnQg
# VHJ1c3RlZCBHNCBSU0E0MDk2IFNIQTI1NiBUaW1lU3RhbXBpbmcgQ0EwggIiMA0G
# CSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDGhjUGSbPBPXJJUVXHJQPE8pE3qZdR
# odbSg9GeTKJtoLDMg/la9hGhRBVCX6SI82j6ffOciQt/nR+eDzMfUBMLJnOWbfhX
# qAJ9/UO0hNoR8XOxs+4rgISKIhjf69o9xBd/qxkrPkLcZ47qUT3w1lbU5ygt69Ox
# tXXnHwZljZQp09nsad/ZkIdGAHvbREGJ3HxqV3rwN3mfXazL6IRktFLydkf3YYMZ
# 3V+0VAshaG43IbtArF+y3kp9zvU5EmfvDqVjbOSmxR3NNg1c1eYbqMFkdECnwHLF
# uk4fsbVYTXn+149zk6wsOeKlSNbwsDETqVcplicu9Yemj052FVUmcJgmf6AaRyBD
# 40NjgHt1biclkJg6OBGz9vae5jtb7IHeIhTZgirHkr+g3uM+onP65x9abJTyUpUR
# K1h0QCirc0PO30qhHGs4xSnzyqqWc0Jon7ZGs506o9UD4L/wojzKQtwYSH8UNM/S
# TKvvmz3+DrhkKvp1KCRB7UK/BZxmSVJQ9FHzNklNiyDSLFc1eSuo80VgvCONWPfc
# Yd6T/jnA+bIwpUzX6ZhKWD7TA4j+s4/TXkt2ElGTyYwMO1uKIqjBJgj5FBASA31f
# I7tk42PgpuE+9sJ0sj8eCXbsq11GdeJgo1gJASgADoRU7s7pXcheMBK9Rp6103a5
# 0g5rmQzSM7TNsQIDAQABo4IBXTCCAVkwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNV
# HQ4EFgQUuhbZbU2FL3MpdpovdYxqII+eyG8wHwYDVR0jBBgwFoAU7NfjgtJxXWRM
# 3y5nP+e6mK4cD08wDgYDVR0PAQH/BAQDAgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMI
# MHcGCCsGAQUFBwEBBGswaTAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNl
# cnQuY29tMEEGCCsGAQUFBzAChjVodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20v
# RGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNydDBDBgNVHR8EPDA6MDigNqA0hjJodHRw
# Oi8vY3JsMy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNybDAg
# BgNVHSAEGTAXMAgGBmeBDAEEAjALBglghkgBhv1sBwEwDQYJKoZIhvcNAQELBQAD
# ggIBAH1ZjsCTtm+YqUQiAX5m1tghQuGwGC4QTRPPMFPOvxj7x1Bd4ksp+3CKDaop
# afxpwc8dB+k+YMjYC+VcW9dth/qEICU0MWfNthKWb8RQTGIdDAiCqBa9qVbPFXON
# ASIlzpVpP0d3+3J0FNf/q0+KLHqrhc1DX+1gtqpPkWaeLJ7giqzl/Yy8ZCaHbJK9
# nXzQcAp876i8dU+6WvepELJd6f8oVInw1YpxdmXazPByoyP6wCeCRK6ZJxurJB4m
# wbfeKuv2nrF5mYGjVoarCkXJ38SNoOeY+/umnXKvxMfBwWpx2cYTgAnEtp/Nh4ck
# u0+jSbl3ZpHxcpzpSwJSpzd+k1OsOx0ISQ+UzTl63f8lY5knLD0/a6fxZsNBzU+2
# QJshIUDQtxMkzdwdeDrknq3lNHGS1yZr5Dhzq6YBT70/O3itTK37xJV77QpfMzmH
# QXh6OOmc4d0j/R0o08f56PGYX/sr2H7yRp11LB4nLCbbbxV7HhmLNriT1ObyF5lZ
# ynDwN7+YAN8gFk8n+2BnFqFmut1VwDophrCYoCvtlUG3OtUVmDG0YgkPCr2B2RP+
# v6TR81fZvAT6gt4y3wSJ8ADNXcL50CN/AAvkdgIm2fBldkKmKYcJRyvmfxqkhQ/8
# mJb2VVQrH4D6wPIOK+XW+6kvRBVK5xMOHds3OBqhK/bt1nz8MIIFjTCCBHWgAwIB
# AgIQDpsYjvnQLefv21DiCEAYWjANBgkqhkiG9w0BAQwFADBlMQswCQYDVQQGEwJV
# UzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQu
# Y29tMSQwIgYDVQQDExtEaWdpQ2VydCBBc3N1cmVkIElEIFJvb3QgQ0EwHhcNMjIw
# ODAxMDAwMDAwWhcNMzExMTA5MjM1OTU5WjBiMQswCQYDVQQGEwJVUzEVMBMGA1UE
# ChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSEwHwYD
# VQQDExhEaWdpQ2VydCBUcnVzdGVkIFJvb3QgRzQwggIiMA0GCSqGSIb3DQEBAQUA
# A4ICDwAwggIKAoICAQC/5pBzaN675F1KPDAiMGkz7MKnJS7JIT3yithZwuEppz1Y
# q3aaza57G4QNxDAf8xukOBbrVsaXbR2rsnnyyhHS5F/WBTxSD1Ifxp4VpX6+n6lX
# FllVcq9ok3DCsrp1mWpzMpTREEQQLt+C8weE5nQ7bXHiLQwb7iDVySAdYyktzuxe
# TsiT+CFhmzTrBcZe7FsavOvJz82sNEBfsXpm7nfISKhmV1efVFiODCu3T6cw2Vbu
# yntd463JT17lNecxy9qTXtyOj4DatpGYQJB5w3jHtrHEtWoYOAMQjdjUN6QuBX2I
# 9YI+EJFwq1WCQTLX2wRzKm6RAXwhTNS8rhsDdV14Ztk6MUSaM0C/CNdaSaTC5qmg
# Z92kJ7yhTzm1EVgX9yRcRo9k98FpiHaYdj1ZXUJ2h4mXaXpI8OCiEhtmmnTK3kse
# 5w5jrubU75KSOp493ADkRSWJtppEGSt+wJS00mFt6zPZxd9LBADMfRyVw4/3IbKy
# Ebe7f/LVjHAsQWCqsWMYRJUadmJ+9oCw++hkpjPRiQfhvbfmQ6QYuKZ3AeEPlAwh
# HbJUKSWJbOUOUlFHdL4mrLZBdd56rF+NP8m800ERElvlEFDrMcXKchYiCd98THU/
# Y+whX8QgUWtvsauGi0/C1kVfnSD8oR7FwI+isX4KJpn15GkvmB0t9dmpsh3lGwID
# AQABo4IBOjCCATYwDwYDVR0TAQH/BAUwAwEB/zAdBgNVHQ4EFgQU7NfjgtJxXWRM
# 3y5nP+e6mK4cD08wHwYDVR0jBBgwFoAUReuir/SSy4IxLVGLp6chnfNtyA8wDgYD
# VR0PAQH/BAQDAgGGMHkGCCsGAQUFBwEBBG0wazAkBggrBgEFBQcwAYYYaHR0cDov
# L29jc3AuZGlnaWNlcnQuY29tMEMGCCsGAQUFBzAChjdodHRwOi8vY2FjZXJ0cy5k
# aWdpY2VydC5jb20vRGlnaUNlcnRBc3N1cmVkSURSb290Q0EuY3J0MEUGA1UdHwQ+
# MDwwOqA4oDaGNGh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3Vy
# ZWRJRFJvb3RDQS5jcmwwEQYDVR0gBAowCDAGBgRVHSAAMA0GCSqGSIb3DQEBDAUA
# A4IBAQBwoL9DXFXnOF+go3QbPbYW1/e/Vwe9mqyhhyzshV6pGrsi+IcaaVQi7aSI
# d229GhT0E0p6Ly23OO/0/4C5+KH38nLeJLxSA8hO0Cre+i1Wz/n096wwepqLsl7U
# z9FDRJtDIeuWcqFItJnLnU+nBgMTdydE1Od/6Fmo8L8vC6bp8jQ87PcDx4eo0kxA
# GTVGamlUsLihVo7spNU96LHc/RzY9HdaXFSMb++hUD38dglohJ9vytsgjTVgHAID
# yyCwrFigDkBjxZgiwbJZ9VVrzyerbHbObyMt9H5xaiNrIv8SuFQtJ37YOtnwtoeW
# /VvRXKwYw02fc7cBqZ9Xql4o4rmUMYIDdjCCA3ICAQEwdzBjMQswCQYDVQQGEwJV
# UzEXMBUGA1UEChMORGlnaUNlcnQsIEluYy4xOzA5BgNVBAMTMkRpZ2lDZXJ0IFRy
# dXN0ZWQgRzQgUlNBNDA5NiBTSEEyNTYgVGltZVN0YW1waW5nIENBAhALrma8Wrp/
# lYfG+ekE4zMEMA0GCWCGSAFlAwQCAQUAoIHRMBoGCSqGSIb3DQEJAzENBgsqhkiG
# 9w0BCRABBDAcBgkqhkiG9w0BCQUxDxcNMjQxMjEwMTEwNjExWjArBgsqhkiG9w0B
# CRACDDEcMBowGDAWBBTb04XuYtvSPnvk9nFIUIck1YZbRTAvBgkqhkiG9w0BCQQx
# IgQgBR8PgfreAp9mPLqFYAiiGpIwlC7EmTlTz7Hic82+TYwwNwYLKoZIhvcNAQkQ
# Ai8xKDAmMCQwIgQgdnafqPJjLx9DCzojMK7WVnX+13PbBdZluQWTmEOPmtswDQYJ
# KoZIhvcNAQEBBQAEggIAVoNabdJCtHo9xuerg963wb7sEmlbSaiYReWuwMYwuxDP
# FIAWqBEhLMGBt+2gc7phoVWfSAcF5t7/SbOVXX3tWMQsf0SFCsRDxL34JYYf94E1
# FSqGIHmgL8vLYAsSX0edw/gotpzJV5Ywk+DnZioN4250fhMahEJ6F1OGBe1WD7on
# BB4DyOuG1nVkkNLpWl98xaMPfp6qmwrYajc+QY4ylENUn1AvbMKy8oOc/fMvkBHZ
# JIZd1n43IgVwhvpWCU+BSU6XGJdI4ZGg1bcVBf40Pnjrdd1rTbRCuUN2u98QwFgD
# Y6I63s4Aw6HPEUqXvaac6o/Z8vxMjVs0ujOlD2BbSdnyuIyopwKKVH7+opfiGPsc
# CJnfRedWzo/TBiAmAOcIwsxrujhOFahuQrbcypK3LVlVPw4Gh5/aHwN53NP01HPP
# 4Swh5cH3kwuuzAy+8GzMwYJVfdok4dmgcvoXn/fK4CXaJX1OCoKCSuy0kQne4tB0
# A5xYqC53bdu0VuDELskhZKj0/AzVhqStKMSFKBhXAKGgXq2h0F5VVq9MoeaXna06
# BnQcMbn7RDAba/b2ZietygDmwW6dvzY+QtoP8ZTh1GsBm30WnikecZWnBcHIr4U9
# VJHHv+xjlSVH7qAMD5uHVhWxdNc+aa3+AZKWkeqZrVrfAwa/EtT30//3z7JSJFk=
# SIG # End signature block
